@@ -1,7 +1,7 @@
 package Finance::Robinhood::Market;
 use 5.010;
 use Carp;
-our $VERSION = "0.02_001";
+our $VERSION = "0.01";
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -24,22 +24,21 @@ sub todays_hours {
 
 =head1 NAME
 
-Finance::Robinhood::Market - Basic Market Information
+Finance::Robinhood::Market - Basic market information
 
 =head1 SYNOPSIS
 
     use Finance::Robinhood::Market;
 
-    my $MC = Finance::Robinhood::instrument('APPL');
+    my $MC = Finance::Robinhood::Instrument::search('APPL');
     my $market = $MC->market();
     print $market->acronym() . ' is based in ' . $market->city();
 
 =head1 DESCRIPTION
 
 This class represents a single financial market. Objects are usually
-created by Finance::Robinhood. If you're looking for information about the
-market where a particular security is traded, use
-C<<<Finance::Robinhood::instrument($symbol)->market()>>>.
+created by Finance::Robinhood. If you intend to create your own, please use
+C<Finance::Robinhood->instrument(...)->market()>.
 
 =head1 METHODS
 
