@@ -1,7 +1,7 @@
 package Finance::Robinhood::Position;
 use 5.010;
 use Carp;
-our $VERSION = "0.02_001";
+our $VERSION = "0.01";
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -58,6 +58,8 @@ This class has several getters and a few methods as follows...
 
 =head2 C<account( )>
 
+    my $acct = $order->account();
+
 Returns the Finance::Robinhood::Account object related to this order.
 
 =head2 C<average_buy_price( )>
