@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = "0.02_001";
+our $VERSION = "0.01";
 use Moo;
 use JSON::Tiny qw[decode_json];
 use strictures 2;
@@ -29,7 +29,7 @@ sub instruments {
     return $self->_get_rh()->_paginate(
         {results => [
              map {
-                     my ($status, $ins, $raw)
+                 my ($ins)
                      = $self->_get_rh()
                      ->_send_request('GET', $_->{instrument});
                  $ins
@@ -53,7 +53,7 @@ sub bulk_add_symbols {
         );
     return $result ?
         map {
-            my ($status, $instrument, $raw)
+        my ($instrument)
             = $self->_get_rh()->_send_request('GET', $_->{instrument});
         Finance::Robinhood::Instrument->new($instrument)
         } @{$result}
@@ -62,18 +62,15 @@ sub bulk_add_symbols {
 
 sub add_instrument {
     my ($self, $instrument) = @_;
-    my $ret = $self->_get_rh()->_send_request('POST', Finance::Robinhood::endpoint('watchlists') . $self->name() . '/');
-    return $ret;
+    return $self->_get_rh()->_send_request('POST', Finance::Robinhood::endpoint('watchlists') . $self->name() . '/');
 }
 
 sub delete_instrument {
     my ($self, $instrument) = @_;
-    my ($status, $ret) =
+    return
         $self->_get_rh()->_send_request('DELETE',
-              Finance::Robinhood::endpoint('watchlists') . $self->name() . '/' . $instrument->id() . '/');
-    return $status == 204;
+              Finance::Robinhood::endpoint('watchlists') . $self->name() . '/' . $instrument->id() . '/') ? 1 : !1;
 }
-
 1;
 
 =encoding utf-8
@@ -95,28 +92,15 @@ Finance::Robinhood::Watchlist - Persistant List of Financial Instruments
 =head1 DESCRIPTION
 
 Robinhood allows persistant, categorized lists of financial instruments in
-'watchlists'. Watchlists are tied to a user rather than a single
-L<account|Finance::Robinhood::Account>.
+'watchlists'. The 'Default' watchlist is created by the official Robinhood
+apps and are preloaded with popular securities.
 
-If you intend to create your own wishlists, please use
-C<<Finance::Robinhood->create_watchlist( ... )>>.
+If you intend to create your own, please use
+C<Finance::Robinhood->create_watchlist( ... )>.
 
 =head1 METHODS
 
-Watchlists are rather simple in themselves but can be very powerful for
-orgaization. Let's say you have a really short list of stocks you'd really
-like to keep an eye on, you could add just those securities to a watchlist. Or
-You could add a watchlist for securities in a certain field.
-
-=head2 C<name( )>
-
-Returns the name given to this watchlist. The official apps use a watchlist
-named 'Default'.
-
-=head2 C<instruments( )>
-
-Returns a paginated list of Finance::Robinhood::Instrument objects being kept
-track of in this watchlist.
+Watchlists are rather simple in themselves.
 
 =head2 C<delete_instrument( ... )>
 
@@ -137,8 +121,7 @@ second time will fail.
 
 Add multiple instruments in a single API call and by their symbols with this.
 
-...easier than gathering ::Instrument objects and calling
-C<add_instrument( ... )> for each individual security, right?
+...easier than looping through the symbols yourself, right?
 
 =head1 LEGAL
 
